@@ -13,33 +13,6 @@
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software 
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-//
-// As a special exception to the GNU General Public License, permission is
-// granted for additional uses of the text contained in its release
-// of Bayonne as noted here.
-//
-// This exception is that permission is hereby granted to link Bayonne 
-// with  the Pika MonteCarlo libraries to produce a executable image
-// without requiring MonteCarlo itself to be supplied in source form so
-// long as each source file so linked contains this exclusion.
-//
-// This exception does not however invalidate any other reasons why
-// the resulting executable file might be covered by the GNU General
-// public license or invalidate the licensing requirements of any
-// other component or library.
-//
-// This exception applies only to the code released by OST under the
-// name Bayonne.  If you copy code from other releases into a copy of
-// Bayonne, as the General Public License permits, the exception does not
-// apply to the code that you add in this way.  To avoid misleading
-// anyone as to the status of such modified files, you must delete
-// this exception notice from them.
-//
-// If you write modifications of your own to Bayonne, it is your choice
-// whether to permit this exception to apply to your modifications.
-// If you do not wish that, delete this exception notice, at which
-// point the terms of your modification would be covered under the GPL
-// as explicitly stated in "COPYING".
 
 #include "driver.h"
 #include <sys/ioctl.h>
@@ -95,12 +68,13 @@ bool PhonedevTrunk::idleHandler(TrunkEvent *event)
 		return true;
 	case TRUNK_LINE_WINK:
 	case TRUNK_CPA_DIALTONE:
+	case TRUNK_MAKE_IDLE:
+	case TRUNK_STOP_DISCONNECT:
+		return true;
 	case TRUNK_MAKE_BUSY:
 		flags.trunk = TRUNK_MODE_UNAVAILABLE;
 		handler = &PhonedevTrunk::busyHandler;
 		return true;
-	case TRUNK_MAKE_IDLE:
-		return true;
 	case TRUNK_START_SCRIPT:
 		flags.trunk = TRUNK_MODE_OUTGOING;
 	case TRUNK_RING_START:
