@@ -45,6 +45,14 @@
 #include <bayonne.h>
 #include <cc++/audio.h>
 
+#ifdef	have_montecarlo_h
+#include <montecarlo.h>
+#else
+#ifdef	HAVE_MONTECARLO_H
+#include <MonteCarlo.h>
+#endif
+#endif
+
 #define	PK_VP_RESOURCES (PK_TONE_DETECTION | PK_TONE_GENERATION)
 #define USE_PK_CALL
 #define	MAX_DSP_DEVICES	2
