@@ -44,7 +44,7 @@
 #include "driver.h"
 #include <sys/ioctl.h>
 
-RecordAudio::RecordAudio(TrunkDriver *trunk) :
+PikaRecord::PikaRecord(PikaTrunk *trunk) :
 Service((Trunk *)trunk, keythreads.priAudio()), AudioFile()
 {
 	reset = false;
@@ -52,7 +52,7 @@ Service((Trunk *)trunk, keythreads.priAudio()), AudioFile()
 	clrAudio();
 }
 
-RecordAudio::~RecordAudio()
+PikaRecord::~PikaRecord()
 {
 	struct stat ino;
 	char buffer[12];
@@ -76,7 +76,7 @@ RecordAudio::~RecordAudio()
 	}
 }
 
-timeout_t RecordAudio::Stop(void)
+timeout_t PikaRecord::Stop(void)
 {
 	clrAudio();
 	stopped = true;
@@ -86,10 +86,10 @@ timeout_t RecordAudio::Stop(void)
 		reset = false;
 		PK_AUDIO_Reset(hDsp);
 	}
-	return 120 * ivr.getAudioBuffers() + keythreads.getResetDelay();
+	return 120 * pikaivr.getAudioBuffers() + keythreads.getResetDelay();
 }
 
-void RecordAudio::Initial(void)
+void PikaRecord::Initial(void)
 {
 	unsigned codec, speed, rate, len, count = 0;
 	char buffer[32];
@@ -207,9 +207,9 @@ void RecordAudio::Initial(void)
 	samples = tosamples(getEncoding(), bufsize);
 }
 
-void RecordAudio::Run(void)
+void PikaRecord::Run(void)
 {
-	int buffers = ivr.getAudioBuffers();
+	int buffers = pikaivr.getAudioBuffers();
 	int frame = 0;
 	unsigned len = samples;
 	audioerror_t status = AUDIO_SUCCESS;
@@ -270,7 +270,7 @@ void RecordAudio::Run(void)
 	Success();
 }
 
-bool TrunkDriver::recordHandler(TrunkEvent *event)
+bool PikaTrunk::recordHandler(TrunkEvent *event)
 {
 	unsigned long mask;
 
@@ -280,12 +280,12 @@ bool TrunkDriver::recordHandler(TrunkEvent *event)
 		stopServices();
 	case TRUNK_SERVICE_SUCCESS:
 		TrunkSignal(TRUNK_SIGNAL_STEP);
-		handler = &TrunkDriver::stepHandler;
+		handler = &PikaTrunk::stepHandler;
 		return true;
 	case TRUNK_SERVICE_FAILURE:
 		setSymbol("error", "play-failed");
 		TrunkSignal(TRUNK_SIGNAL_ERROR);
-		handler = &TrunkDriver::stepHandler;
+		handler = &PikaTrunk::stepHandler;
 		return true;
 	case TRUNK_DTMF_KEYUP:
 		mask = (1 << event->parm.dtmf.digit);
@@ -310,7 +310,7 @@ bool TrunkDriver::recordHandler(TrunkEvent *event)
 			setDTMFDetect(true);
 		else
 			Trunk::setDTMFDetect();
-		thread = new RecordAudio(this);
+		thread = new PikaRecord(this);
 		thread->Start();
 		setTimer(data.record.timeout);
 		return true;
