@@ -13,33 +13,6 @@
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software 
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-//
-// As a special exception to the GNU General Public License, permission is
-// granted for additional uses of the text contained in its release
-// of Bayonne as noted here.
-//
-// This exception is that permission is hereby granted to link Bayonne 
-// with  the Pika MonteCarlo libraries to produce a executable image
-// without requiring MonteCarlo itself to be supplied in source form so
-// long as each source file so linked contains this exclusion.
-//
-// This exception does not however invalidate any other reasons why
-// the resulting executable file might be covered by the GNU General
-// public license or invalidate the licensing requirements of any
-// other component or library.
-//
-// This exception applies only to the code released by OST under the
-// name Bayonne.  If you copy code from other releases into a copy of
-// Bayonne, as the General Public License permits, the exception does not
-// apply to the code that you add in this way.  To avoid misleading
-// anyone as to the status of such modified files, you must delete
-// this exception notice from them.
-//
-// If you write modifications of your own to Bayonne, it is your choice
-// whether to permit this exception to apply to your modifications.
-// If you do not wish that, delete this exception notice, at which
-// point the terms of your modification would be covered under the GPL
-// as explicitly stated in "COPYING".
 
 #ifndef	__CCXX_BAYONNE_H__
 #define	__CCXX_BAYONNE_H__
@@ -149,6 +122,7 @@ typedef enum {
 	TRUNK_EXIT_SHELL = 200,	// tgi completion event
 	TRUNK_START_SCRIPT,	// start of script
 	TRUNK_RING_START,	// smdi/integrated answer
+	TRUNK_STOP_DISCONNECT,	// integrated hangup notification
 
 	// in the future these will be used
 
@@ -174,6 +148,12 @@ typedef enum {
 	TRUNK_OFF_HOOK,		// some drivers notify off hook
 	TRUNK_CALLER_ID,	// caller id parse request
 	TRUNK_RINGING_DID,	// did digit ring signal
+	TRUNK_CALL_DETECT,	// ISDN call detected notification
+	TRUNK_CALL_CONNECT,	// ISDN call connection notification
+	TRUNK_CALL_RELEASE,	// ISDN call release notification
+	TRUNK_CALL_ACCEPT,	// ISDN incoming call accepted
+	TRUNK_CALL_RINGING,	// digital T1 incoming call
+	TRUNK_CALL_DISCONNECT,	// digital T1 circuit break
 
 	// basic audio processing events
 
@@ -193,6 +173,12 @@ typedef enum {
 	TRUNK_AUDIO_STOP,	// some drivers may "vox" compress
 	TRUNK_CPA_DIALTONE,	// dialtone heard on the line
 	TRUNK_CPA_BUSYTONE,
+	TRUNK_CPA_RINGING,
+	TRUNK_CPA_INTERCEPT,
+	TRUNK_CPA_NODIALTONE,
+	TRUNK_CPA_NORINGBACK,
+	TRUNK_CPA_NOANSWER,
+	TRUNK_CPA_CONNECT,
 
 	// driver specific events and anomolies
 
@@ -351,6 +337,7 @@ typedef struct
 		char **argv;
 		timeout_t duration;
 		trunkstep_t step;
+		char align[8];
 	} parm;
 } TrunkEvent;
 
@@ -590,6 +577,18 @@ public:
 	inline const char *getLibexec(void)
 		{return getLast("libexec");};
 
+	/**
+	 * Get library tgi exec search path.
+	 */
+	inline const char *getTgipath(void)
+		{return getLast("tgipath");};
+
+	/**
+	 * Get prefix for DSO modules at install.
+	 */
+	inline const char *getLibpath(void)
+		{return getLast("libpath");};
+
 	/**
 	 * Get the primary working storage for writable messages.
 	 */
@@ -1509,6 +1508,13 @@ public:
 	inline void *getSession(void)
 		{return session;};
 
+	/**
+	 * Compute the DTMF digit id of a character.
+	 *
+	 * @return dtmf digit or -1.
+	 */
+	int getDigit(char digit);
+
 	/**
 	 * Logout a session handler.
 	 */
@@ -1626,6 +1632,9 @@ protected:
 	bool login(char **argv);
 	bool startScript(int id, char **argv);
 	bool ringScript(int id, char **argv);
+	bool busyLine(char **argv);
+	bool idleLine(char **argv);
+	bool hangupLine(char **argv);
 
 public:
 	/**
