@@ -13,33 +13,6 @@
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software 
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-//
-// As a special exception to the GNU General Public License, permission is
-// granted for additional uses of the text contained in its release
-// of Bayonne as noted here.
-//
-// This exception is that permission is hereby granted to link Bayonne 
-// with  the Pika MonteCarlo libraries to produce a executable image
-// without requiring MonteCarlo itself to be supplied in source form so
-// long as each source file so linked contains this exclusion.
-//
-// This exception does not however invalidate any other reasons why
-// the resulting executable file might be covered by the GNU General
-// public license or invalidate the licensing requirements of any
-// other component or library.
-//
-// This exception applies only to the code released by OST under the
-// name Bayonne.  If you copy code from other releases into a copy of
-// Bayonne, as the General Public License permits, the exception does not
-// apply to the code that you add in this way.  To avoid misleading
-// anyone as to the status of such modified files, you must delete
-// this exception notice from them.
-//
-// If you write modifications of your own to Bayonne, it is your choice
-// whether to permit this exception to apply to your modifications.
-// If you do not wish that, delete this exception notice, at which
-// point the terms of your modification would be covered under the GPL
-// as explicitly stated in "COPYING".
 
 #include "server.h"
 #include <getopt.h>
@@ -236,7 +209,6 @@ static void tgi(void)
 //		dup2(cfd, 2);
 		close(cfd);
 
-		setenv("PATH", getenv("SERVER_LIBEXEC"), 1);
 		sprintf(buffer, "%s/%s", getenv("SERVER_LIBEXEC"), *argv);
 		getInterp(buffer, argv);
 		execvp(buffer, argv);
@@ -299,6 +271,7 @@ static void initial(int argc, char **argv)
 		{"test", 0, 0, 't'},
 		{"trace", 0, 0, 'T'},
 		{"database", 1, 0, 'a'},
+		{"version", 0, 0, 'V'},
 		{0, 0, 0, 0}};
 
 	static bool daemon = false;
@@ -324,6 +297,9 @@ static void initial(int argc, char **argv)
 	while(EOF != (opt = getopt_long(argc, argv, "TDFhd:p:d:tn:", long_options, &opt_index)))
 		switch(opt)
 		{
+		case 'V':
+			cout << LIB_VERSION << endl;
+			exit(0);
 		case 'T':
 			daemon = false;
 			slog.level(SLOG_DEBUG);
@@ -341,6 +317,8 @@ static void initial(int argc, char **argv)
 			pp = strrchr(prefix, '/');
 #if defined(have_montecarlo_h) || defined(HAVE_MONTECARLO_H)
 			strcpy(pp, "/drivers/pika/pika.ivr");
+#elif defined(HAVE_VPBAPI_H)
+			strcpy(pp, "/drivers/vpb/vpb.ivr");
 #elif defined(HAVE_LINUX_TELEPHONY_H)
 			strcpy(pp, "/drivers/phonedev/phonedev.ivr");
 #else
@@ -426,6 +404,7 @@ static void initial(int argc, char **argv)
 	setenv("SERVER_SOFTWARE", "bayonne", 1);
 	setenv("SERVER_VERSION", "2.0", 1);
 	setenv("SERVER_TOKEN", keyserver.getToken(), 1);
+	setenv("PATH", keypaths.getTgipath(), 1);
 
 	slog(SLOG_INFO) << "TGI VERSION 2.0";
 	slog() << "; driver=" << plugins.getDriverName();
